package de.ozgcloud.eingang.router;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import de.ozgcloud.eingang.common.formdata.PostfachAddressIdentifier;
import de.ozgcloud.eingang.common.formdata.ServiceKonto;
import de.ozgcloud.eingang.common.formdata.StringBasedIdentifier;
import de.ozgcloud.eingang.common.formdata.ServiceKonto.PostfachAddress;
import de.ozgcloud.vorgang.common.GrpcObject;
import de.ozgcloud.vorgang.common.grpc.GrpcObjectMapper;
import de.ozgcloud.vorgang.vorgang.GrpcPostfachAddress;
import de.ozgcloud.vorgang.vorgang.GrpcServiceKonto;

@Component
class ServiceKontoMapper {

	@Autowired
	private GrpcObjectMapper grpcObjectMapper;

	public GrpcServiceKonto toServiceKonto(ServiceKonto serviceKonto) {
		return GrpcServiceKonto.newBuilder()
				.setType(serviceKonto.getType())
				.addAllPostfachAddresses(getPostfachAddresses(serviceKonto))
				.build();
	}

	private List<GrpcPostfachAddress> getPostfachAddresses(ServiceKonto serviceKonto) {
		return serviceKonto.getPostfachAddresses().stream().map(this::fromPostfachAddress).toList();
	}

	private GrpcPostfachAddress fromPostfachAddress(PostfachAddress postfachAddress) {
		return GrpcPostfachAddress.newBuilder()
				.setVersion(postfachAddress.getVersion())
				.setType(postfachAddress.getType())
				.setIdentifier(mapFromIdentifier(postfachAddress.getIdentifier()))
				.build();
	}

	GrpcObject mapFromIdentifier(PostfachAddressIdentifier identifier) {
		return grpcObjectMapper.fromMap(Map.of(StringBasedIdentifier.POSTFACH_ID_FIELD, getStringBasedValue(identifier)));
	}

	private String getStringBasedValue(PostfachAddressIdentifier identifier) {
		return ((StringBasedIdentifier) identifier).getPostfachId();
	}
}