/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.semantik;

import java.util.Objects;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.router.VorgangService;
import de.ozgcloud.eingang.semantik.enginebased.EngineBasedSemantikAdapter;
import de.ozgcloud.eingang.semantik.formbased.FormBasedSemantikAdapter;

@Service
public class SemantikAdapter {

	@Autowired(required = false)
	private EngineBasedSemantikAdapter engineBasedAdapter;
	@Autowired
	private FormBasedSemantikAdapter formBasedAdapter;

	@Autowired
	private VorgangService vorgangService;

	public String processFormData(FormData formData) {
		formData = parseByEngineAdapter(formData);
		formData = parseByFormAdapter(formData);

		return vorgangService.createVorgang(formData);
	}

	private FormData parseByEngineAdapter(FormData formData) {
		if (Objects.nonNull(engineBasedAdapter)) {
			return engineBasedAdapter.parseFormData(formData);
		}
		return formData;
	}

	private FormData parseByFormAdapter(FormData formData) {
		return formBasedAdapter.parseFormData(formData);
	}
}