{{/* vim: set filetype=mustache: */}}

{{/* Truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec) */}}
{{/* Name */}}
{{- define "app.name" -}}
{{- default .Release.Name | toString | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Namespace */}}
{{- define "app.namespace" -}}
{{- default .Release.Namespace | toString | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Version */}}
{{- define "app.version" -}}
{{- default .Chart.Version | toString | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Chart: Name + Version */}}
{{- define "app.chart" -}}
{{ printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end -}}

{{/* Managed-by -> On Helm, this value is always Helm */}}
{{- define "app.managedBy" -}}
{{- default .Release.Service | toString | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Default Labels: Helm recommended best-practice labels https://helm.sh/docs/chart_best_practices/labels/ */}}
{{- define "app.defaultLabels" }}
app.kubernetes.io/instance: afm-adapter
app.kubernetes.io/managed-by: {{ include "app.managedBy" . }}
app.kubernetes.io/name: {{ include "app.name" . }}
app.kubernetes.io/part-of: ozgcloud
app.kubernetes.io/version: {{ include "app.version" . }}
app.kubernetes.io/namespace: {{ include "app.namespace" . }}
helm.sh/chart: {{ include "app.chart" . }}
ozg-component: eingangsadapter
{{- end -}}

{{- define "app.matchLabels" }}
app.kubernetes.io/name: {{ include "app.name" . }}
app.kubernetes.io/namespace: {{ include "app.namespace" . }}
{{- end -}}

{{- define "app.imagePullSecret" }}
{{- with .Values.imageCredentials }}
{{- printf "{\"auths\":{\"%s\":{\"username\":\"%s\",\"password\":\"%s\",\"email\":\"%s\",\"auth\":\"%s\"}}}" .registry .username .password .email (printf "%s:%s" .username .password | b64enc) | b64enc }}
{{- end }}
{{- end }}

{{- define "app.envSpringProfiles" }}
{{- if (.Values.env).overrideSpringProfiles -}}
{{ printf "%s" (.Values.env).overrideSpringProfiles }}
{{- else -}}
{{ printf "oc, %s" (include "app.ozgcloudEnvironment" . ) }}
{{- end -}}
{{- end -}}

{{- define "app.ozgcloudEnvironment" -}}
{{- required "Environment muss angegeben sein" (.Values.ozgcloud).environment -}}
{{- end -}}

{{- define "app.ozgcloudBezeichner" -}}
{{ $length := len (.Values.ozgcloud).bezeichner }}
{{- if ge 46 $length -}}
{{ (.Values.ozgcloud).bezeichner }}
{{- else -}}
{{ required (printf "Bezeichner %s ist zu lang (max. 46 Zeichen)" (.Values.ozgcloud).bezeichner) nil }}
{{- end -}}
{{- end -}}

{{- define "app.ingress.host" }}
{{- if (.Values.ingress).adapterBezeichner }}
{{- printf "%s-%s.%s" (include "app.ozgcloudBezeichner" .) .Values.ingress.adapterBezeichner .Values.baseUrl }}
{{- else if eq (.Values.image).name "formsolutions-adapter" }}
{{- printf "%s-fs.%s" (include "app.ozgcloudBezeichner" .) .Values.baseUrl }}
{{- else if eq (.Values.image).name "formcycle-adapter" }}
{{- printf "%s-formcycle.%s" (include "app.ozgcloudBezeichner" .) .Values.baseUrl }}
{{- else }}
{{- printf "%s-afm.%s" (include "app.ozgcloudBezeichner" .) .Values.baseUrl }}
{{- end }}
{{- end -}}

{{- define "app.serviceAccountName" -}}
{{- if (.Values.serviceAccount).name }}
{{- printf "%s" .Values.serviceAccount.name }}
{{- else if eq (.Values.image).name "intelliform-adapter" }}
{{- printf "afm-adapter-service-account" }}
{{- else if eq (.Values.image).name "formsolutions-adapter" }}
{{- printf "fs-adapter-service-account" }}
{{- else if eq (.Values.image).name "formcycle-adapter" }}
{{- printf "formcycle-adapter-service-account" }}
{{- else if eq (.Values.image).name "enterprise-adapter" }}
{{- printf "enterprise-adapter-service-account" }}
{{- end }}
{{- end -}}